@@ -37,19 +37,19 @@ class HtmlExpressionWriter : public AbstractExpressionVisitor
     public:
         HtmlExpressionWriter(const Object* o);
         
-        virtual QVariant visit(const None* var);
-        virtual QVariant visit(const Ci* var);
-        virtual QVariant visit(const Cn* var);
-        virtual QVariant visit(const Container* var);
-        virtual QVariant visit(const Operator* var);
-        virtual QVariant visit(const Vector* var);
-        virtual QVariant visit(const List* l);
-        virtual QVariant visit(const Apply* a);
-        virtual QVariant visit(const CustomObject* c);
-        virtual QVariant visit(const Matrix* c);
-        virtual QVariant visit(const MatrixRow* c);
+        virtual QVariant visit(const None* var) override;
+        virtual QVariant visit(const Ci* var) override;
+        virtual QVariant visit(const Cn* var) override;
+        virtual QVariant visit(const Container* var) override;
+        virtual QVariant visit(const Operator* var) override;
+        virtual QVariant visit(const Vector* var) override;
+        virtual QVariant visit(const List* l) override;
+        virtual QVariant visit(const Apply* a) override;
+        virtual QVariant visit(const CustomObject* c) override;
+        virtual QVariant visit(const Matrix* c) override;
+        virtual QVariant visit(const MatrixRow* c) override;
         
-        QVariant result() const { return m_result; }
+        QVariant result() const override { return m_result; }
         
     private:
         template <class T>
